#
# spec file for package libaec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libaec
Version:        1.1.3
Release:        1.3
Summary:        Adaptive Entropy Coding library
License:        BSD-2-Clause
Group:          Productivity/Archiving/Compression
URL:            https://gitlab.dkrz.de/k202009/libaec
Source:         https://gitlab.dkrz.de/k202009/libaec/-/archive/v%{version}/%{name}-v%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++

%description
Libaec provides lossless compression of signed or unsigned integers
(samples) of sizes 1 to 32 bits wide. The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations.

%package -n libaec0
Summary:        Adaptive Entropy Coding library
Group:          System/Libraries

%description -n libaec0
Libaec provides lossless compression of signed or unsigned integers
(samples) of sizes 1 to 32 bits wide. The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-3 and 120.0-G-2.

%package devel
Summary:        Development files for libaec (Adaptive Entropy Coding library)
Group:          Development/Libraries/C and C++
Requires:       libaec0 = %{version}-%{release}

%description devel
Development files for libaec (Adaptive Entropy Coding library), a lossless
compression library for low entropy data.

%package -n libsz2
Summary:        Lossless compression library for scientific data
Group:          System/Libraries

%description -n libsz2
Lossless compression library for scientific data. Libsz2 is a drop-in
replacement for the SZIP library (http://www.hdfgroup.org/doc_resource/SZIP).

%package -n sz2-devel
Summary:        Development files for libsz2
Group:          Development/Libraries/C and C++
Requires:       libaec-devel = %{version}-%{release}
Requires:       libsz2 = %{version}-%{release}
Provides:       libsz2-devel = %{version}-%{release}
Obsoletes:      libsz2-devel < %{version}-%{release}

%description -n sz2-devel
Header files for libsz2, a drop-in replacement for the
SZIP library (http://www.hdfgroup.org/doc_resource/SZIP).

%prep
%autosetup -n "%{name}-v%{version}"

%build
%cmake
%cmake_build

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%install
%cmake_install
find %{buildroot}%{_libdir} -type f -name "*.a" -delete -print
mkdir -p %{buildroot}%{_libdir}/cmake/%{name}
mv %{buildroot}/usr/cmake/*.cmake %{buildroot}%{_libdir}/cmake/%{name}/
rmdir %{buildroot}/usr/cmake

%post -n libaec0 -p /sbin/ldconfig
%post -n libsz2 -p /sbin/ldconfig
%postun -n libaec0 -p /sbin/ldconfig
%postun -n libsz2 -p /sbin/ldconfig

%files -n libaec0
%license LICENSE.txt
%doc README.md CHANGELOG.md
%{_libdir}/libaec.so.0*

%files devel
%{_libdir}/cmake/%{name}
%{_includedir}/libaec.h
%{_libdir}/libaec.so

%files -n libsz2
%license LICENSE.txt
%doc README.SZIP
%{_libdir}/libsz.so.2*

%files -n sz2-devel
%{_includedir}/szlib.h
%{_libdir}/libsz.so

%changelog
* Thu Mar 21 2024 Manfred Schwarb <manfred99@gmx.ch>
- Update to version 1.1.3:
  * Fix compiler warnings
* Mon Nov  6 2023 Manfred Schwarb <manfred99@gmx.ch>
- remove optional binary installation to please Factory
* Mon Oct 30 2023 Manfred Schwarb <manfred99@gmx.ch>
- make deploying aec executable conditional and default off, can
    be added back later if needed
* Mon Oct 16 2023 Manfred Schwarb <manfred99@gmx.ch>
- Update to version 1.1.2:
  * Compile issue with MSVC
* Fri Sep 29 2023 Manfred Schwarb <manfred99@gmx.ch>
- put back aec executable
- Update to version 1.1.1:
  * Grab correct offsets when encoding
  * Rename aec executable to graec, will not be installed any more
  * The include file libaec.h now contains version information
  * Support for decoding data ranges by Eugen Betke
* Mon Sep 27 2021 Manfred Schwarb <manfred99@gmx.ch>
- Update to version 1.0.6:
  * Improved cmake for mingw and MSVC by Milos Komarcevic
* Tue Sep  7 2021 Manfred Schwarb <manfred99@gmx.ch>
- remove doc/patent.txt and patent comment in spec file, as the new
    standard 121.0-B-3 declares:
    "At time of publication, the specifications of this Recommended
    Standard are not known to be the subject of patent rights."
* Wed Jun 16 2021 Manfred Schwarb <manfred99@gmx.ch>
- add license file also to libsz2 package
- move misplaced *.cmake files
- delete static libraries
- remove spec file fallback for too old cmake versions
- Update to version 1.0.5:
  * Updated documentation to new 121.0-B-3 standard. The new standard mainly clarifies
    and explicitly defines special cases which could be ambiguous or misleading
    in previous revisions.
    Existing compressed data is still compatible with this version of the library
    and compressed data produced by this version can be uncompressed with previous versions.
  * Modernized CMake
  * Better CMake integration with HDF5 by Jan-Willem Blokland
* Mon Feb 25 2019 manfred99@gmx.ch
- Update to version 1.0.4:
  * added test data
  * fixed include file
- Update to version 1.0.3:
  * Improvements to testing and fuzzing by Kurt Schwehr
  * fixed various ubsan issues
* Tue Oct 24 2017 junghans@votca.org
- version bump to v1.0.2
  * C99 requirement in all build systems
* Mon Oct  2 2017 dimstar@opensuse.org
- Add baselibs.conf: build libsz2 and libaec0 for biarch setups
  (needed by hdf5).
* Wed Aug 23 2017 jengelh@inai.de
- Fix RPM groups, and slightly expand summaries.
* Mon Jul 24 2017 manfred99@gmx.ch
- Add fallback for SLE12 and older opensuse versions: use autoconf/make
* Mon Jul 24 2017 manfred99@gmx.ch
- fix compilation, package now needs c99 standard
- avoid rpmlint warning "W: description-shorter-than-summary"
- do not add README.SZIP twice
* Mon Jul 17 2017 junghans@votca.org
- version bump to v1.0.1, switch to cmake
  * Fixes: Potential security vulnerabilities in decoder exposed by libFuzzer.
  * Added: Fuzz target for decoding and encoding.
* Thu Jul  6 2017 badshah400@gmail.com
- Rename subpackage libsz2-devel to sz2-devel (see, e.g.
  https://build.opensuse.org/request/show/508143);
  provide/obsolete old devel package libsz2-devel for consistency.
- Minor cleanup of specfile:
  * Move README.SZIP to libsz2 subpackage, this is the shared lib
    actually replacing szip.
  * Use `find` instead of `rm -f` to clean up libtool archives.
  * For devel packages, remove release number dependency on
    corresponding shared libs.
* Wed Jun 28 2017 jengelh@inai.de
- Remove static libraries.
- Trim description a little.
* Fri Jun  9 2017 manfred99@gmx.ch
- minor spec cleanup to comply with spec-cleaner
* Thu Jun  1 2017 manfred99@gmx.ch
- Don't require lock-step of libsz and libaec
* Wed Feb  8 2017 manfred99@gmx.ch
- Update to version 1.0.0:
  * Include CCSDS test data with libaec
  * Better compatibility with OSX for make check
  * Allow Cygwin to build DLLs
- remove 121B2TestData.zip from repo, now included in source, adjust spec
* Tue Nov 29 2016 manfred99@gmx.ch
- Update to version 0.3.4:
  * Pad incomplete last line when in SZ compatibility mode
- tighten spec dependencies
* Sun Jul 31 2016 manfred99@gmx.ch
- split into 4 subpackages
* Wed Jul  6 2016 manfred99@gmx.ch
- initial packaging
